@@ -85,11 +85,6 @@ class Application(object):
         self.__requests = {}
         self.__requestUrls = {}
         self.__requestUrlRegex = []
-        self.init()
-
-    # Overridable initialization function
-    def init(self):
-        pass
 
     # Overridable WSGI entry point
     def call(self, environ, start_response):
@@ -359,7 +354,7 @@ class Application(object):
 
     # Generator to recursively load all modules
     @staticmethod
-    def loadModules(moduleDir, moduleExt = '.py', moduleNamePartsPrefix = (), moduleNamePartsIgnore = ()):
+    def __loadModules(moduleDir, moduleExt = '.py', moduleNamePartsPrefix = (), moduleNamePartsIgnore = ()):
 
         # Does the path exist?
         if not os.path.isdir(moduleDir):
@@ -397,7 +392,7 @@ class Application(object):
     # Recursively load all requests in a directory
     def loadRequests(self, moduleDir, moduleExt = '.py', moduleNamePartsPrefix = ()):
 
-        for module in self.loadModules(moduleDir, moduleExt = moduleExt, moduleNamePartsPrefix = moduleNamePartsPrefix):
+        for module in self.__loadModules(moduleDir, moduleExt = moduleExt, moduleNamePartsPrefix = moduleNamePartsPrefix):
             for moduleAttr in dir(module):
                 request = getattr(module, moduleAttr)
                 if isinstance(request, Request):
